@@ -1,11 +1,9 @@
 package ll
 
 import (
-	"os"
 	"sync/atomic"
 	"time"
 
-	"github.com/olekukonko/ll/lh"
 	"github.com/olekukonko/ll/lx"
 )
 
@@ -14,16 +12,7 @@ import (
 // a logger instance. The logger is initialized with default settings: enabled, Debug level,
 // flat namespace style, and a text handler to os.Stdout. It is thread-safe due to the Logger
 // struct’s mutex.
-var defaultLogger = &Logger{
-	enabled:         true,                         // Initially enabled
-	level:           lx.LevelDebug,                // Minimum log level set to Debug
-	namespaces:      defaultStore,                 // Shared namespace store for enable/disable states
-	context:         make(map[string]interface{}), // Empty context for global fields
-	style:           lx.FlatPath,                  // Flat namespace style (e.g., [parent/child])
-	handler:         lh.NewTextHandler(os.Stdout), // Default text handler to os.Stdout
-	middleware:      make([]Middleware, 0),        // Empty middleware chain
-	stackBufferSize: 4096,                         // Buffer size for stack traces
-}
+var defaultLogger = New("")
 
 // Handler sets the handler for the default logger.
 // It configures the output destination and format (e.g., text, JSON) for logs emitted by
@@ -41,9 +30,9 @@ func Handler(handler lx.Handler) *Logger {
 // the specified level are ignored. Returns the default logger for method chaining.
 // Example:
 //
-//	ll.Level(lx.LevelWarn)
-//	ll.Info("Ignored") // No output
-//	ll.Warn("Logged")  // Output: [] WARN: Logged
+//	ll.Level(lx.LevelInfo)
+//	ll.Warn("Ignored") // Inactive output
+//	ll.Info("Logged")  // Output: [] INFO: Logged
 func Level(level lx.LevelType) *Logger {
 	return defaultLogger.Level(level)
 }
@@ -76,7 +65,7 @@ func NamespaceEnable(path string) *Logger {
 // Example:
 //
 //	ll.NamespaceDisable("app/db")
-//	ll.Clone().Namespace("db").Info("Query") // No output
+//	ll.Clone().Namespace("db").Info("Query") // Inactive output
 func NamespaceDisable(path string) *Logger {
 	return defaultLogger.NamespaceDisable(path)
 }
@@ -233,16 +222,25 @@ func Panicf(format string, args ...any) {
 }
 
 // If creates a conditional logger that logs only if the condition is true using the default logger.
-// It returns a Conditional struct that wraps the default logger, enabling conditional logging methods.
-// Thread-safe via the Logger’s mutex.
-// Example:
-//
-//	ll.If(true).Info("Logged")   // Output: [] INFO: Logged
-//	ll.If(false).Info("Ignored") // No output
 func If(condition bool) *Conditional {
 	return defaultLogger.If(condition)
 }
 
+// IfErr creates a conditional logger that logs only if the error is non-nil using the default logger.
+func IfErr(err error) *Conditional {
+	return defaultLogger.IfErr(err)
+}
+
+// IfErrAny creates a conditional logger that logs only if AT LEAST ONE error is non-nil using the default logger.
+func IfErrAny(errs ...error) *Conditional {
+	return defaultLogger.IfErrAny(errs...)
+}
+
+// IfErrOne creates a conditional logger that logs only if ALL errors are non-nil using the default logger.
+func IfErrOne(errs ...error) *Conditional {
+	return defaultLogger.IfErrOne(errs...)
+}
+
 // Context creates a new logger with additional contextual fields using the default logger.
 // It preserves existing context fields and adds new ones, returning a new logger instance
 // to avoid mutating the default logger. Thread-safe with write lock.
@@ -260,8 +258,8 @@ func Context(fields map[string]interface{}) *Logger {
 //
 //	ll.AddContext("user", "alice")
 //	ll.Info("Action") // Output: [] INFO: Action [user=alice]
-func AddContext(key string, value interface{}) *Logger {
-	return defaultLogger.AddContext(key, value)
+func AddContext(pairs ...any) *Logger {
+	return defaultLogger.AddContext(pairs...)
 }
 
 // GetContext returns the default logger’s context map of persistent key-value fields.
@@ -269,7 +267,7 @@ func AddContext(key string, value interface{}) *Logger {
 // Example:
 //
 //	ll.AddContext("user", "alice")
-//	ctx := ll.GetContext() // Returns map[string]interface{}{"user": "alice"}
+//	ctx := ll.GetContext() // Returns map[string]interface{}{"user": "alice"}k
 func GetContext() map[string]interface{} {
 	return defaultLogger.GetContext()
 }
@@ -371,7 +369,7 @@ func StackSize(size int) *Logger {
 //	    }
 //	    return nil
 //	}))
-//	ll.Info("Ignored") // No output
+//	ll.Info("Ignored") // Inactive output
 //	mw.Remove()
 //	ll.Info("Logged") // Output: [] INFO: Logged
 func Use(fn lx.Handler) *Middleware {
@@ -395,7 +393,7 @@ func Remove(m *Middleware) {
 //
 //	ll.Use(someMiddleware)
 //	ll.Clear()
-//	ll.Info("No middleware") // Output: [] INFO: No middleware
+//	ll.Info("Inactive middleware") // Output: [] INFO: Inactive middleware
 func Clear() *Logger {
 	return defaultLogger.Clear()
 }
@@ -472,6 +470,37 @@ func Measure(fns ...func()) time.Duration {
 	return defaultLogger.Measure(fns...)
 }
 
+// Labels temporarily attaches one or more label names to the logger for the next log entry.
+// Labels are typically used for metrics, benchmarking, tracing, or categorizing logs in a structured way.
+//
+// The labels are stored atomically and intended to be short-lived, applying only to the next
+// log operation (or until overwritten by a subsequent call to Labels). Multiple labels can
+// be provided as separate string arguments.
+//
+// Example usage:
+//
+//	logger := New("app").Enable()
+//
+//	// Add labels for a specific operation
+//	logger.Labels("load_users", "process_orders").Measure(func() {
+//	    // ... perform work ...
+//	}, func() {
+//	    // ... optional callback ...
+//	})
+func Labels(names ...string) *Logger {
+	return defaultLogger.Labels(names...)
+}
+
+// Since creates a timer that will log the duration when completed
+// If startTime is provided, uses that as the start time; otherwise uses time.Now()
+//
+//	defer logger.Since().Info("request")        // Auto-start
+//	logger.Since(start).Info("request")         // Manual timing
+//	logger.Since().If(debug).Debug("timing")    // Conditional
+func Since(start ...time.Time) *SinceBuilder {
+	return defaultLogger.Since(start...)
+}
+
 // Benchmark logs the duration since a start time at Info level using the default logger.
 // It calculates the time elapsed since the provided start time and logs it with "start",
 // "end", and "duration" fields. Thread-safe via the Logger’s mutex.
@@ -516,7 +545,7 @@ func Err(errs ...error) {
 // Example:
 //
 //	ll.Shutdown()
-//	ll.Info("Ignored") // No output
+//	ll.Info("Ignored") // Inactive output
 //	ll.Start()
 //	ll.Info("Logged")  // Output: [] INFO: Logged
 func Start() {
@@ -529,7 +558,7 @@ func Start() {
 // Example:
 //
 //	ll.Shutdown()
-//	ll.Info("Ignored") // No output
+//	ll.Info("Ignored") // Inactive output
 func Shutdown() {
 	atomic.StoreInt32(&systemActive, 0)
 }
@@ -551,7 +580,7 @@ func Active() bool {
 // Example:
 //
 //	ll.Disable()
-//	ll.Info("Ignored") // No output
+//	ll.Info("Ignored") // Inactive output
 //	ll.Enable()
 //	ll.Info("Logged")  // Output: [] INFO: Logged
 func Enable() *Logger {
@@ -564,7 +593,7 @@ func Enable() *Logger {
 // Example:
 //
 //	ll.Disable()
-//	ll.Info("Ignored") // No output
+//	ll.Info("Ignored") // Inactive output
 func Disable() *Logger {
 	return defaultLogger.Disable()
 }
@@ -586,8 +615,8 @@ func Dbg(any ...interface{}) {
 // Example:
 //
 //	ll.Dump([]byte{0x41, 0x42}) // Outputs hex/ASCII dump
-func Dump(any interface{}) {
-	defaultLogger.Dump(any)
+func Dump(values ...interface{}) {
+	defaultLogger.Dump(values...)
 }
 
 // Enabled returns whether the default logger is enabled for logging.
@@ -657,6 +686,22 @@ func Mark(names ...string) {
 // It is similar to Dbg but formats the output as JSON for better readability. It is thread-safe and respects
 // the logger’s configuration (e.g., enabled, level, suspend, handler, middleware).
 func Output(values ...interface{}) {
+	defaultLogger.output(2, values...)
+
+}
+
+// Inspect logs one or more values in a **developer-friendly, deeply introspective format** at Info level.
+// It includes the caller file and line number, and reveals **all fields** — including:
+func Inspect(values ...interface{}) {
 	o := NewInspector(defaultLogger)
 	o.Log(2, values...)
 }
+
+func Apply(opts ...Option) *Logger {
+	return defaultLogger.Apply(opts...)
+
+}
+
+func Toggle(v bool) *Logger {
+	return defaultLogger.Toggle(v)
+}
